# `finsim`


[![CircleCI](https://circleci.com/gh/stephenhky/FinanceSimulation.svg?style=svg)](https://circleci.com/gh/stephenhky/FinanceSimulation.svg)
[![GitHub release](https://img.shields.io/github/release/stephenhky/FinanceSimulation.svg?maxAge=3600)](https://github.com/stephenhky/FinanceSimulation/releases)
[![Updates](https://pyup.io/repos/github/stephenhky/FinanceSimulation/shield.svg)](https://pyup.io/repos/github/stephenhky/FinanceSimulation/)
[![Python 3](https://pyup.io/repos/github/stephenhky/FinanceSimulation/python-3-shield.svg)](https://pyup.io/repos/github/stephenhky/FinanceSimulation/)


## Introduction

Financial assets estimation, and portfolio management.
